#
# spec file for package python-schema
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-schema
Version:        0.7.7
Release:        1.5
Summary:        Data validation library
License:        MIT
URL:            https://github.com/keleshev/schema
Source:         https://files.pythonhosted.org/packages/source/s/schema/schema-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
BuildArch:      noarch

%python_subpackages

%description
Schema is a library for validating Python data structures, such as those
obtained from config-files, forms, external services or command-line
parsing, converted from JSON/YAML (or something else) to Python data-types.

%prep
%autosetup -p1 -n schema-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest test_schema.py

%files %{python_files}
%doc README.rst
%license LICENSE-MIT
%{python_sitelib}/schema.py
%pycache_only %{python_sitelib}/__pycache__/schema*
%{python_sitelib}/schema-%{version}.dist-info

%changelog
* Mon Oct 28 2024 Dirk Müller <dmueller@suse.com>
- update to 0.7.7:
  * type hints
  * fix: Fix setuptools not finding the schema package
- drop remove-old-python-support.patch (upstream)
* Thu Aug 11 2022 Steve Kowalik <steven.kowalik@suse.com>
- Drop patch python-schema-no-mock.patch:
  * Replaced by the below path.
- Add patch remove-old-python-support.patch:
  * Remove support for old Python versions as well mock and contextlib2.
- Clean up {Build,}Requires as a result.
* Wed May  4 2022 pgajdos@suse.com
- version update to 0.7.5
  * Full subclass support for nested schemas.
  * Don't double-format errors. fixes #240 (#247) [Leif Ryge]
  * Fix "Unknown format code" in Python 3.8 (#245) [Denis Blanchette]
  * JSON Schema: Allow using $ref when schema is not a dict (#244) [Denis Blanchette]
  * JSON Schema: Set additionalProperties true when dict contains str as key (#243) [Denis Blanchette]
- do not require python-mock for build
- added patches
  fix https://github.com/keleshev/schema/pull/273
  + python-schema-no-mock.patch
* Thu Sep 10 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to 0.7.3
  * JSON Schema: Support schemas where the root is not a dict.
  * Do not drop previous errors within an Or criterion.
- Update to 0.7.2
  * Set the contextlib dependency as a minimum, rather than fixed.
* Thu Mar 26 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.7.1
  * JSON Schema: Fix allOf and oneOf with only one condition
  * JSON Schema: Fix using falsy values as default
  * Add 3.7 to "schema is tested with..." list
  * JSON schema now rendering using references
* Tue Mar 26 2019 pgajdos@suse.com
- version update to 0.7.0
  * Add an is_valid method to the schema
  * Fix typo in schema.py: vaidated->validated
  * Fix callable check under PyPy2
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue May 15 2018 toddrme2178@gmail.com
- Update to 0.6.7
  * Implement Const validator to keep data unchanged
  * Implement Forbidden.
  * added __hash__ and __eq__ based on sub-schema to Optional
- Use license tag
* Fri Oct 20 2017 toddrme2178@gmail.com
- initial version
